futex_wake

Function futex_wake 

pub fn futex_wake(futex: &Atomic<u32>) -> bool
Available on Android or Linux only.
Wakes up one thread that’s blocked on futex_wait on this futex.

Returns true if this actually woke up such a thread, or false if no thread was waiting on this futex.

On some platforms, this always returns false.